#define MSG_TIMEOUT "Timeout"
#define MSG_CAPABILITIES "Ofrmgen att ndra mjligheter"
#define MSG_CLIENT_CLOSED_CNX "Klienten avbrt anslutningen"
#define MSG_CLIENT_READ_ERR "Lsfel frn klienten"
#define MSG_CANT_OPEN_CNX "Kan ej ansluta"
#define MSG_CANT_CREATE_DATA_SOCKET "Kan ej skapa data socket"
#define MSG_DEBUG_CLIENT_IS "Klientens adress r"
#define MSG_SYNTAX_ERROR_IP "Syntax error i IP adress"
#define MSG_PORT_SUCCESSFUL "PORT kommando lyckades"
#define MSG_ONLY_IPV4V6 "Endast std fr IPv4 och IPv6 (1,2)"
#define MSG_ONLY_IPV4 "Endast std fr IPv4 (1)"
#define MSG_TIMEOUT_PARSER "Timeout - frsk att skriva snabbare nsta gng"
#define MSG_LINE_TOO_LONG "Raden r fr lng"
#define MSG_LOG_OVERFLOW "Klienten frskte fylla kommandoradsbufferten"
#define MSG_GOODBYE "Adj. Du har laddat upp %llu och laddat ned %llu kbytes."
#define MSG_DEBUG_COMMAND "Kommando"
#define MSG_IS_YOUR_CURRENT_LOCATION "r din nuvarande plats"
#define MSG_NOT_LOGGED_IN "Du r inte inloggad"
#define MSG_AUTH_UNIMPLEMENTED "Skerhetsfunktionen r ej installerad"
#define MSG_NO_FILE_NAME "Filnamn saknas"
#define MSG_NO_DIRECTORY_NAME "Biblioteksnamn saknas"
#define MSG_NO_RESTART_POINT "Omstartsplats saknas"
#define MSG_ABOR_SUCCESS "Eftersom du ser det hr mste ABOR lyckats"
#define MSG_MISSING_ARG "Argument saknas"
#define MSG_GARBAGE_FOUND "Skrp efter vrde"
#define MSG_VALUE_TOO_LARGE "Vrdet r fr stort"
#define MSG_IDLE_TIME "Idle time r %lu sekunder"
#define MSG_SITE_HELP "Fljande SITE kommandon knns igen"
#define MSG_BAD_CHMOD "Felaktig behrighet"
#define MSG_UNKNOWN_EXTENSION "r en oknd extension"
#define MSG_XDBG_OK "XDBG kommando lyckades, debug niv r nu %d"
#define MSG_UNKNOWN_COMMAND "Oknt kommando"
#define MSG_TIMEOUT_NOOP "Timeout (ingen inmatning under %lu sekunder)"
#define MSG_TIMEOUT_DATA "Timeout (inga nya data under %lu sekunder)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Du r redan inloggad"
#define MSG_ANY_PASSWORD "Vilket lsenord som helst fungerar"
#define MSG_ANONYMOUS_LOGGED "Anonym anvndare r inloggad"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonym anvndare loggade in i virtuell FTP"
#define MSG_USER_OK "Anvndare %s OK. Lsenord krvs"
#define MSG_CANT_DO_TWICE "Vi kan inte gra det i denna session"
#define MSG_UNABLE_SECURE_ANON "Ofrmgen att starta sker anonym FTP"
#define MSG_BANDWIDTH_RESTRICTED "Din bandbredd r begrnsad"
#define MSG_NO_PASSWORD_NEEDED "Vilket lsenord som helst fungerar"
#define MSG_NOTRUST "Jag kan tyrr inte lita p Dig"
#define MSG_WHOAREYOU "Var vnlig och tala om vem Du r"
#define MSG_AUTH_FAILED "Behrighetskontroll misslyckades"
#define MSG_AUTH_TOOMANY "Fr mnga behrighetskontroller har misslyckats"
#define MSG_NO_HOMEDIR "Hembibliotek r inte tillgngligt - avbryter"
#define MSG_NO_HOMEDIR2 "%s existerar inte eller kan ej ns"
#define MSG_START_SLASH "Startar i /"
#define MSG_USER_GROUP_ACCESS "Anvndare %s har grupptillhrighet"
#define MSG_FXP_SUPPORT "Denna server stdjer FXP verfringar"
#define MSG_RATIO "Du mste respektera en %u:%u (UL/DL) kvot"
#define MSG_CHROOT_FAILED "Ofrmgen att starta ett skert chroot() skal"
#define MSG_CURRENT_DIR_IS "OK. Nuvarande bibliotek r %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Nuvarande begrnsade bibliotek r %s"
#define MSG_IS_NOW_LOGGED_IN "%s har loggat in"
#define MSG_CANT_CHANGE_DIR "Kan ej ndra bibliotek till %s"
#define MSG_PATH_TOO_LONG "Skvgen r fr lng"
#define MSG_CANT_PASV "Du kan ej anvnda PASV p IPv6 anslutningar. Anvnd EPSV istllet."
#define MSG_CANT_PASSIVE "Kan ej ppna en passiv anslutning"
#define MSG_PORTS_BUSY "Alla reserverade TCP portar r upptagna"
#define MSG_GETSOCKNAME_DATA "Kan ej identifiera lokal data socket"
#define MSG_GETPEERNAME "Kan ej identifiera lokal socket"
#define MSG_INVALID_IP "Felaktig adress"
#define MSG_NO_EPSV "Var vnlig och anvnd en IPv6 klient med EPSV std"
#define MSG_BAD_PORT "Jag ansluter ej till portar < 1024"
#define MSG_NO_FXP "Jag ppnar ej en anslutning till %s (endast till %s)"
#define MSG_FXP "FXP verfring: frn %s till %s"
#define MSG_NO_DATA_CONN "Ingen datafrbindelse"
#define MSG_ACCEPT_FAILED "Anslutningen kunde ej accepteras"
#define MSG_ACCEPT_SUCCESS "Datafrbindelsen accepteras"
#define MSG_CNX_PORT_FAILED "Kan ej ppna datafrbindelse till port %d"
#define MSG_CNX_PORT "Ansluter till port %d"
#define MSG_ANON_CANT_MKD "Anonyma anvndare har inte behrighet att skapa bibliotek"
#define MSG_ANON_CANT_RMD "Anonyma anvndare har inte behrighet att radera bibliotek"
#define MSG_ANON_CANT_RENAME "Anonyma anvndare har inte behrighet att flytta eller byta namn p filer"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonyma anvndare kan inte ndra rttigheter"
#define MSG_GLOB_NO_MEMORY "Minnet r slut pga globbing av %s"
#define MSG_PROBABLY_DENIED "(Detta betyder antagligen \"tkomst nekad\")"
#define MSG_GLOB_READ_ERROR "Lsfel under globbing av %s"
#define MSG_GLOB_NO_MATCH "Ingen trff fr %s i %s"
#define MSG_CHMOD_FAILED "Kan ej ndra rttigheter p %s"
#define MSG_CHMOD_SUCCESS "Rttigheter ndrade p %s"
#define MSG_CHMOD_TOTAL_FAILURE "Jag kunde inte ndra ngon rttighet"
#define MSG_ANON_CANT_DELETE "Anonyma anvndare kan inte radera filer"
#define MSG_ANON_CANT_OVERWRITE "Anonyma anvndare kan inte skriva ver existerande filer"
#define MSG_DELE_FAILED "Kan ej radera %s"
#define MSG_DELE_SUCCESS "Raderade %s"
#define MSG_DELE_TOTAL_FAILURE "Ingen fil r raderad"
#define MSG_LOAD_TOO_HIGH \
    "Belastningen var %3.2f nr du upprttade frbindelse. Vi tillter ej nedladdningar\n" \
    "av anonyma anvndare nr belastningen r spass hg. Uppladdningar r alltid\n" \
    "tilltna."
#define MSG_OPEN_FAILURE "Kan ej ppna %s"
#define MSG_OPEN_FAILURE2 "Kan ej ppna den filen"
#define MSG_STAT_FAILURE "Kan ej finna filstorleken"
#define MSG_STAT_FAILURE2 "Kan ej kontrollera filens existens"
#define MSG_REST_TOO_LARGE_FOR_FILE "Omstart offset %lld r fr stor fr filstorlek %lld."
#define MSG_REST_RESET "Omstart offset r satt till 0"
#define MSG_NOT_REGULAR_FILE "Jag kan bara hmta normala filer"
#define MSG_NOT_MODERATED \
    "Denna fil har laddats upp av en anonym anvndare. Den har nnu\n" \
    "inte blivit godknd fr nedladdning av systemadministratr."
#define MSG_RATIO_DENIAL \
    "Uppladdning/nedladdningskvoten r  %u:%u .\n" \
    "Du har laddat upp %llu Kb och laddat ned %llu Kb.\n" \
    "Vnligen ladda upp litet goa grejer och frsk suga senare."
#define MSG_NO_MORE_TO_DOWNLOAD "Inget kvar att ladda ned"
#define MSG_WINNER "Datorn r Din vn. Lita p datorn"
#define MSG_KBYTES_LEFT "%.1f kbytes att ladda ned"
#define MSG_ABORTED "verfring avbruten"
#define MSG_DATA_WRITE_FAILED "Fel under write to data anslutning"
#define MSG_DATA_READ_FAILED "Fel under read from data anslutning"
#define MSG_MMAP_FAILED "Ofrmgen att lgga filen i minnet"
#define MSG_WRITE_FAILED "Fel d data skrivs till fil"
#define MSG_TRANSFER_RATE_M "%.3f sekunder (uppmtt hr), %.2f Mbytes per sekund"
#define MSG_TRANSFER_RATE_K "%.3f sekunder (uppmtt hr), %.2f Kbytes per sekund"
#define MSG_TRANSFER_RATE_B "%.3f sekunder (uppmtt hr), %.2f bytes per sekund"
#define MSG_SPACE_FREE_M "%.1f Mbytes ledigt diskutrymme"
#define MSG_SPACE_FREE_K "%f Kbytes ledigt diskutrymme"
#define MSG_DOWNLOADED "nedladdad"
#define MSG_REST_NOT_NUMERIC "REST behver numerisk parameter"
#define MSG_REST_ASCII_STRICT "Svarsmarkr mste vara 0 i ASCII mode"
#define MSG_REST_ASCII_WORKAROUND "Startar om vid %lld. Men vi r i ASCII mode"
#define MSG_REST_SUCCESS "Startar om vid %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Biblioteksnamnet r ej tilltet"
#define MSG_SANITY_FILE_FAILURE "Filnamnet %s r ej tilltet"
#define MSG_MKD_FAILURE "Kan ej skapa bibliotek"
#define MSG_MKD_SUCCESS "Biblioteket har skapats"
#define MSG_RMD_FAILURE "Kan ej radera biblioteket"
#define MSG_RMD_SUCCESS "Biblioteket har raderats"
#define MSG_TIMESTAMP_FAILURE "Kan ej erhlla time stamp"
#define MSG_MODE_ERROR "Endast std fr ASCII och binary modes"
#define MSG_CREATE_FAILURE "Kan ej skapa fil"
#define MSG_ABRT_ONLY "ABRT r det enda tilltna kommandot vid uppladdning"
#define MSG_UPLOAD_PARTIAL "delvis uppladdad"
#define MSG_REMOVED "raderad"
#define MSG_UPLOADED "uppladdad"
#define MSG_GMTIME_FAILURE "Kunde ej erhlla lokal tid"
#define MSG_TYPE_8BIT_FAILURE "Endast std fr 8-bit bytes , Hall - vakna!"
#define MSG_TYPE_UNKNOWN "Oknd TYPE"
#define MSG_TYPE_SUCCESS "TYPE r nu"
#define MSG_STRU_FAILURE "Endast std fr F(ile)"
#define MSG_MODE_FAILURE "Anvnd S(tream) mode"
#define MSG_RENAME_ABORT "Avbryter tidigare namnbytesoperation"
#define MSG_RENAME_RNFR_SUCCESS "RNFR accepteras - filen existerar, redo fr destination"
#define MSG_FILE_DOESNT_EXIST "Filen existerar ej"
#define MSG_RENAME_ALREADY_THERE "RENAME misslyckades - destinationsfilen finns redan"
#define MSG_RENAME_NORNFR "Behver RNFR fre RNTO"
#define MSG_RENAME_FAILURE "Byt namn/flytta misslyckades"
#define MSG_RENAME_SUCCESS "Filen har bytt namn eller flyttats"
#define MSG_NO_SUPERSERVER "Kr pure-ftpd i en super-server (t ex tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Kan ej hitta 'ftp' kontot"
#define MSG_CONF_ERR "Konfigurationsfel"
#define MSG_NO_VIRTUAL_FILE "Virtuella anvndares filnamn saknas"
#define MSG_ILLEGAL_THROTTLING "Illegalt vrde fr throttling"
#define MSG_ILLEGAL_TRUSTED_GID "Illegal betrodd gid fr chroot"
#define MSG_ILLEGAL_USER_LIMIT "Illegal anvndargrns"
#define MSG_ILLEGAL_FACILITY "Oknt namn"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Felaktig LDAP konfigurationsfil"
#define MSG_ILLEGAL_LOAD_LIMIT "Illegal belastningsgrns"
#define MSG_ILLEGAL_PORTS_RANGE "Illegalt portspann"
#define MSG_ILLEGAL_LS_LIMITS "Illegal 'ls' begrnsning"
#define MSG_ILLEGAL_FORCE_PASSIVE "Illegal tvingad IP fr passiva anslutningar"
#define MSG_ILLEGAL_RATIO "Illegal upp-/nedladdningskvot"
#define MSG_ILLEGAL_UID_LIMIT "Illegal uid begrnsning"
#define MSG_ILLEGAL_OPTION "Oknt krningsval"
#define MSG_LDAP_MISSING_BASE "LDAPBaseDN saknas i LDAP konfigurationsfil"
#define MSG_LDAP_WRONG_PARMS "Felaktiga LDAP parametrar"
#define MSG_NEW_CONNECTION "Nyanslutning frn %s"
#define MSG_WELCOME_TO "Vlkommen till"
#define MSG_MAX_USERS "%lu anvndare (maximala antalet) r redan inloggade"
#define MSG_NB_USERS "Du r anvndare nummer %d av %d tilltna"
#define MSG_WELCOME_TIME "Lokal tid r nu %02d:%02d. Server port: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Endast anonym FTP r tillten"
#define MSG_RATIOS_EVERYONE "RATIOS r aktiverat fr ALLA:"
#define MSG_RATIOS_ANONYMOUS "ANONYMA anvndare utstts fr en UL/DL kvot:"
#define MSG_RATIOS_RULE "fr att ladda ned %u Mb, r det ndvndigt att ladda upp %u Mb."
#define MSG_INFO_IDLE_M "Du kommer att kopplas ned efter %lu minuters inaktivitet."
#define MSG_INFO_IDLE_S "Du kommer att kopplas ned efter %lu sekunders inaktivitet."
#define MSG_CANT_READ_FILE "Kan ej lsa [%s]"
#define MSG_LS_TRUNCATED "Utdata trunkeras till %u trffar"
#define MSG_LS_SUCCESS "%u trffar totalt"
#define MSG_LOGOUT "Logout."
#define MSG_AUTH_FAILED_LOG "Behrighetskontroll misslyckas fr anvndare [%s]"
#define MSG_ILLEGAL_UMASK "Ogiltig umask"
#define MSG_STANDALONE_FAILED "Kan ej starta standalone server"
#define MSG_NO_ANONYMOUS_LOGIN "Detta r ett privat system - Ingen anonym login"
#define MSG_ANONYMOUS_ANY_PASSWORD "Vilket lsenord som helst fungerar"
#define MSG_MAX_USERS_IP "Fr mnga anslutningar (%lu) frn denna IP"
#define MSG_ACTIVE_DISABLED "Aktiv mode r avstngd"
#define MSG_TRANSFER_SUCCESSFUL "Filen har vefrts"
#define MSG_NO_DISK_SPACE "Disken r full - Vnligen ladda upp senare"
#define MSG_OUT_OF_MEMORY "Minnet r slut"
#define MSG_ILLEGAL_TRUSTED_IP "Ogiltig betrodd IP adress"
#define MSG_NO_ASCII_RESUME "ASCII resume r osker, radera filen frst"
#define MSG_UNKNOWN_ALTLOG "Oknt loggningsformat"
#define MSG_ACCOUNT_DISABLED "Kan ej logga in som [%s]: kontot r avstngt"
#define MSG_SQL_WRONG_PARMS "Fel SQL parametrar"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Felaktig SQL konfigurationsfil"
#define MSG_SQL_MISSING_SERVER "Server saknas i SQL konfigurationsfil"
#define MSG_SQL_DOWN "SQL servern frefaller vara nere"
#define MSG_ILLEGAL_QUOTA "Ogiltig kvot"
#define MSG_QUOTA_FILES "%llu filer anvnda (%d%%) - authorized: %llu files"
#define MSG_QUOTA_SIZE "%llu Kbytes anvnda (%d%%) - Tilltet: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Kvoten verskriden: %s kommer inte att sparas"
#define MSG_AUTH_UNKNOWN "Oknd behrighetskontroll"
#define MSG_PDB_BROKEN "Kan ej lsa den indexerade puredb filen (eller gammalt format) - Frsk med pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s r ett alias fr %s."
#define MSG_ALIASES_UNKNOWN "Oknt alias %s."
#define MSG_ALIASES_BROKEN_FILE "Skadad alias fil"
#define MSG_ALIASES_LIST "Fljande alias r tillgngliga :"
#define MSG_PERUSER_MAX "Jag kan inte acceptera fler n %lu anslutningar frn en och samma anvndare"
#define MSG_IPV6_OK "IPv6 anslutningar r ocks vlkomna till denna server"
#define MSG_TLS_INFO "SSL/TLS: Anvnder %s med %s, %d bitars kryptering"
#define MSG_TLS_WEAK "SSL/TLS: Krypteringen r fr svag"
#define MSG_TLS_NEEDED "Tyvrr r sessioner i klartext inte tilltna p denna server.\n" \
    "Vnligen teranslut och anvnd SSL/TLS fr kad skerhet."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
